@@ -39,7 +39,7 @@ APP_ALLOWED_HOSTS = [
     "127.0.0.1",
     "invenio-dev01.tugraz.at",
     "invenio-test.tugraz.at",
-    "repository.tugraz.at"
+    "repository.tugraz.at",
 ]
 """Allowed Hosts"""
 
@@ -53,6 +53,9 @@ APP_DEFAULT_SECURE_HEADERS = {
             "'unsafe-inline'",
             "'unsafe-eval'",
             "blob:",
+            "ub-support.tugraz.at",  # zammad contact form
+            "api.datacite.org/dois",  # datacite
+            "api.test.datacite.org/dois",  # datacite test
         ],
     },
     "content_security_policy_report_only": False,
@@ -156,7 +159,7 @@ SECURITY_CHANGEABLE = False
 SECURITY_RECOVERABLE = False
 """Allow password recovery by users."""
 
-SECURITY_REGISTERABLE = True
+SECURITY_REGISTERABLE = False
 """"Allow users to register.
 
 With this variable set to "False" users will not be
@@ -213,11 +216,11 @@ RECAPTCHA_PRIVATE_KEY = None
 # https://invenio-rdm-records.readthedocs.io/en/latest/configuration.html
 #
 # Custom Access Right
-RDM_RECORDS_CUSTOM_VOCABULARIES = {
-    'access_right': {
-        'path': join(
-            dirname(abspath(__file__)),
-            'restrictions', 'access_right', 'access_right_limit.csv'
-        )
-    }
-}
+# RDM_RECORDS_CUSTOM_VOCABULARIES = {
+#     'access_right': {
+#         'path': join(
+#             dirname(abspath(__file__)),
+#             'restrictions', 'access_right', 'access_right_limit.csv'
+#         )
+#     }
+# }
